/* indices.do is called by decomp after mergedata has created the files  */


/*  generate price indices for each exporter in each market */

	ren  val val_jim 
	ren quant q_jim 
	gen p_jim = val_jim / q_jim

	/*  rest of world exports to market m in category i */

		/* first calc world exports to market m in category i */

		egen val_wim = sum(val_jim), by(imp hs)
		egen q_wim = sum(q_jim), by(imp hs)

		/*  net off j's exports to get world less j -- wj is world less j */

		gen val_wjim = val_wim - val_jim
		gen q_wjim = q_wim - q_jim

		gen p_wjim = val_wjim / q_wjim

	
	/*  calculate importance weights s for each i,j,m */

		/*  calculate nominal val for each exporter j x market m and rest of world to market m in j's categories i */

		egen val_jm = sum(val_jim), by(exp imp)		/* value of j's shipments to market m, over j's cats i */
		egen val_wjm = sum(val_wjim), by(exp imp)		/* val world less j ship to mkt m, in j's cats i */


		gen s_jim = val_jim / val_jm    			/* share of i in j's exports to market m */
		gen s_wjim = val_wjim / val_wjm			/* share of i in w-j exports to market m */

		/* category weights */

	gen wnum_jim = (s_jim - s_wjim)/(ln(s_jim) - ln(s_wjim))	    /* log mean of j and w-j shares of cat i, mkt m*/
		
		egen wsum_jim = sum(wnum_jim), by(exp imp)			/* sum of wnum over j's cats */

		gen w_jim = wnum_jim / wsum_jim

	
	/*  calculate price index for j relative to w-j for each import market */

		egen lnPind_jm = sum(w_jim * ln(p_jim/p_wjim)), by(exp imp)


/* generate OVER, IM, EM margins and Q index for each exporter x market .  "all" denotes that the sum runs
		over all categories, not just over the categories that j ships in */

	egen val_all_wm = sum(val_jim), by(imp)

	gen val_all_wjm = val_all_wm - val_jm

	gen OVER_jm = val_jm / val_all_wjm

	gen INT_jm = val_jm / val_wjm

	gen EXT_jm = OVER_jm / INT_jm
	
	gen lnQind_jm = ln(INT_jm) - lnPind_jm

/* generate overall price index for exporter in all markets*/


		
	/*  calculate importance weights s for each j,m */

		/*  calculate nominal val for each exporter j and rest of world to all markets  */

		egen val_j = sum(val_jm), by(exp)			/* value of j's shipments to all markets */
		egen val_wj = sum(val_all_wjm), by(exp)		/* val world less j shipments to all j's markets  */


		gen s_jm = val_jm / val_j    				/* share of m in j's exports  */
		gen s_wjm = val_all_wjm / val_wj				/* share of m in w-j exports  */

		/* market weights */

	gen	anum_jm = (s_jm - s_wjm)/(ln(s_jm) - ln(s_wjm))	    /* log mean of j and w-j shares of mkt m*/
		
		egen asum_jm = sum(anum_jm), by(exp)			/* sum of wnum over j's */

		gen a_jm = anum_jm / asum_jm
	

/*  calculate overall price and quantity index for j relative to w-j  */

egen lnPind_j = sum(a_jm * lnPind_jm), by(exp)

egen lnQind_j = sum(a_jm * lnQind_jm), by(exp)

egen lnINT_j = sum(a_jm * ln(INT_jm)), by(exp)		/* overall intensive margin for j */

egen lnEXT_j = sum(a_jm * ln(EXT_jm)), by(exp)		/* overall intensive margin for j */

gen lnOVER_j = lnINT_j + lnEXT_j





	

	/* collapse this all down to one observation per country */

	collapse (mean) lnOVER_j lnINT_j lnEXT_j lnPind_j lnQind_j , by(exp)


